@@ -107,16 +107,6 @@ public class ParsedSentence extends Atom implements Serializable
 		return idString;
 	}
 
-	/* Obsolete, do not use */
-	public RelexInfo getRI() {
-		return new RelexInfo(sentence);
-	}
-
-	/* Obsolete, do not use */
-	public void setRI(RelexInfo s) {
-		sentence = s;
-	}
-
 	public Sentence getSentence() {
 		return sentence;
 	}
@@ -182,9 +172,24 @@ public class ParsedSentence extends Atom implements Serializable
 	 */
 	public String getOrigWord(int i)
 	{
-		FeatureNode fn = getWordAsNode(i).get("orig_str");
-		if (fn == null) return null;
-		return fn.getValue();
+		return LinkableView.getOrigWordString(getWordAsNode(i));
+	}
+
+	/**
+	 * Return the part-of-speech of the i'th word in the sentence
+	 */
+	public String getPOS(int i)
+	{
+		return LinkableView.getPOS(getWordAsNode(i));
+	}
+
+	/**
+	 * Return the offset, in the original sentence, to the first
+	 * character of the i'th word in the sentence.
+	 */
+	public int getStartChar(int i)
+	{
+		return LinkableView.getStartChar(getWordAsNode(i));
 	}
 
 	public void addWord(FeatureNode w)
