@@ -57,7 +57,7 @@ import relex.tree.PhraseTree;
 
 /**
  * The RelationExtractor class provides the central processing
- * point for parsing sentences and extracting semantic
+ * point for parsing sentences and extracting dependency
  * relationships from them.  The main() proceedure is usable
  * as a stand-alone document analyzer; it supports several
  * flags modifying the displayed output.
@@ -83,7 +83,7 @@ public class RelationExtractor
 	/** Syntax processing */
 	private LGParser parser;
 
-	/** Semantic processing */
+	/** Dependency processing */
 	private SentenceAlgorithmApplier sentenceAlgorithmApplier;
 
 	/** Penn tree-bank style phrase structure markup. */
@@ -344,7 +344,7 @@ public class RelationExtractor
 			" [-l (show parse links)]" +
 			" [-m (show parse metadata)]" +
 			" [-n max number of parses to display]" +
-			" [-o (show opencog XML output)]" +
+			" [-o (show opencog scheme output)]" +
 			" [--pa (show phrase-based lexical chunks)]" +
 			" [--pb (show pattern-based lexical chunks)]" +
 			" [--pc (show relational lexical chunks)]" +
