@@ -26,7 +26,17 @@ import java.net.ServerSocket;
 import java.net.Socket;
 // import relex.output.SimpleView;
 // import relex.frame.Frame;
-import relex.output.OpenCogXML;
+import relex.output.OpenCogScheme;
+
+/**
+ * The Server class provides a very simple socket-based parse server.
+ * It will listen for plain-text input sentences on port 4444, and will
+ * generate OpenCog output.  
+ *
+ * It is intended that this server be used by OpenCog agents to process
+ * text; the text is sent from opencog to this server, and the returned
+ * parses are then further processed by OpenCog.
+ */
 
 public class Server
 {
@@ -41,15 +51,16 @@ public class Server
 	{
 		RelationExtractor r = new RelationExtractor(false);
 		// Frame frame = new Frame();
-		OpenCogXML opencog = new OpenCogXML();
+		OpenCogScheme opencog = new OpenCogScheme();
 		Server s = new Server();
 		ServerSocket listen_sock = null;
 		try {
 			listen_sock = new ServerSocket(s.listen_port);
 		} catch (IOException e) {
-			System.out.println("Listen failed on port " + s.listen_port);
+			System.err.println("Error: Listen failed on port " + s.listen_port);
 			System.exit(-1);
 		}
+		System.err.println("Info: Listening on port " + s.listen_port);
 
 		while(true)
 		{
@@ -65,51 +76,62 @@ public class Server
 				continue;
 			}
 
-System.out.println("duude got accept");
+			System.err.println("Info: Socket accept");
 			BufferedReader in = new BufferedReader(new InputStreamReader(ins));
 			PrintWriter out = new PrintWriter(outs, true);
 
 			try {
-	 			while(out_sock.isConnected()) {
-					String line = in.readLine();
-					if (line == null)
-						break;
-					Sentence sntc = r.processSentence(line);
-					if (sntc.getParses().size() == 0)
-					{
-						out.println("no parses");
-						continue;
-					}
-					ParsedSentence p = sntc.getParses().get(0);
-
-					/*
-					out.println(p.getPhraseString());
-
-					String fin = SimpleView.printRelationsAlt(p);
-					String[] fout = frame.process(fin);
-					for (int i=0; i < fout.length; i++) {
-						out.println(fout[i]);
-					}
-					*/
-					
-					opencog.setParse(p);
-					out.println(opencog.toString());
+				String line = in.readLine();
+				if (line == null)
+					continue;
+				System.err.println("Info: recv input: \"" + line + "\"");
+				Sentence sntc = r.processSentence(line);
+				if (sntc.getParses().size() == 0)
+				{
+					out.println("; NO PARSES");
+					continue;
 				}
+				ParsedSentence parse = sntc.getParses().get(0);
+
+				/*
+				out.println(parse.getPhraseString());
+
+				String fin = SimpleView.printRelationsAlt(p);
+				String[] fout = frame.process(fin);
+				for (int i=0; i < fout.length; i++) {
+					out.println(fout[i]);
+				}
+				*/
+					
+				opencog.setParse(parse);
+				out.println(opencog.toString());
+
+				// Add a special tag to tell the cog server that it's
+				// just recieved a brand new sentence. The OpenCog scheme
+				// code depends on this being visible, in order to find
+				// the new sentence.
+				out.println("(ListLink");
+				out.println("   (AnchorNode \"# New Parsed Sentence\")");
+				out.println("   (SentenceNode \"" + sntc.getID() + "\")");
+				out.println(")");
+
+				out.println("; END OF SENTENCE");
 
 				out.close();
+				System.err.println("Info: Closed printer");
 			} catch (IOException e) {
-				System.out.println("Processing input failed");
+				System.err.println("Error: Processing input failed");
 				continue;
 			}
 
 			try {
 				out_sock.close();
+				System.err.println("Info: Closed socket");
 			} catch (IOException e) {
-				System.out.println("Socket close failed");
+				System.err.println("Error: Socket close failed");
 				continue;
 			}
 		}
 	}
 }
 
-
